<?php
/**
 * m1 Theme functions and definitions
 *
 * @package m1 Theme
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 770; /* pixels */

if ( ! function_exists( 'm1_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function m1_setup() {

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on m1 Theme, use a find and replace
	 * to change 'm1' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'm1', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Enable support for Post Thumbnails on posts and pages
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 770, 250, true );

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'm1' ),
		'top' => __( 'Top Menu', 'm1' ),
	) );

	/**
	 * Enable support for Post Formats
	 */
	//add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );
}
endif; // m1_setup
add_action( 'after_setup_theme', 'm1_setup' );

/**
 * Setup the WordPress core custom background feature.
 *
 * Use add_theme_support to register support for WordPress 3.4+
 * as well as provide backward compatibility for WordPress 3.3
 * using feature detection of wp_get_theme() which was introduced
 * in WordPress 3.4.
 *
 * @todo Remove the 3.3 support when WordPress 3.6 is released.
 *
 * Hooks into the after_setup_theme action.
 */
function m1_register_custom_background() {
	$args = array(
		'default-color' => 'fafaf9',
		'default-image' => '',
	);

	$args = apply_filters( 'm1_custom_background_args', $args );

	if ( function_exists( 'wp_get_theme' ) ) {
		add_theme_support( 'custom-background', $args );
	} else {
		define( 'BACKGROUND_COLOR', $args['default-color'] );
		if ( ! empty( $args['default-image'] ) )
			define( 'BACKGROUND_IMAGE', $args['default-image'] );
		add_custom_background();
	}
}
add_action( 'after_setup_theme', 'm1_register_custom_background' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function m1_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'm1' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Header', 'm1' ),
		'id'            => 'header-widget-area',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer', 'm1' ),
		'id'            => 'footer-widget-area',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'm1_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function m1_scripts() {
	wp_enqueue_style( 'm1-style', get_stylesheet_uri() );
	
	wp_enqueue_script( 'modernizr', get_template_directory_uri() . '/js/modernizr.js', array( 'jquery' ) );
	
	wp_enqueue_script( 'off-canvas-nav', get_template_directory_uri() . '/js/off-canvas-nav-simple.js', array( 'jquery' ) );
	
	wp_enqueue_script( 'superfish', get_template_directory_uri() . '/js/superfish.js', array( 'jquery' ) );

	wp_enqueue_script( 'm1-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'm1-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}
}
add_action( 'wp_enqueue_scripts', 'm1_scripts' );

// Add ID and CLASS attributes to the first <ul> occurence in wp_page_menu
function add_menuclass($ulclass) {
return preg_replace('/<ul>/', '<ul class="menu">', $ulclass, 1);
}
add_filter('wp_page_menu','add_menuclass');

// Add custom editor styles
function m1_add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}
add_action( 'init', 'm1_add_editor_styles' );

// Theme activation message
/* Display a notice that can be dismissed */

add_action('admin_notices', 'm1_admin_notice');

function m1_admin_notice() {
	global $current_user;
        $user_id = $current_user->ID;
        /* Check that the user hasn't already clicked to ignore the message */
	if ( ! get_user_meta($user_id, 'm1_ignore_notice') ) {
        echo '<div class="updated"><p>'; 
        printf(__('Thanks for choosing the m1 Theme! Please use the <strong><a href="' . get_admin_url() . 'customize.php' . '">theme customizer</a></strong> to customize your theme colors, settings, and more.  For support, docs, upgrades, and more, please visit <a href="http://m1themes.com" target="_blank">m1 Themes.</a> | <a href="%1$s">Hide Notice</a>'), '?m1_nag_ignore=0');
        echo "</p></div>";
	}
}

add_action('admin_init', 'm1_nag_ignore');

function m1_nag_ignore() {
	global $current_user;
        $user_id = $current_user->ID;
        /* If user clicks to ignore the notice, add that to their user meta */
        if ( isset($_GET['m1_nag_ignore']) && '0' == $_GET['m1_nag_ignore'] ) {
             add_user_meta($user_id, 'm1_ignore_notice', 'true', true);
	}
}

// Add a theme customizer link
add_action ('admin_menu', 'm1_customizer_link');
function m1_customizer_link() {
    // add the Customize link to the admin menu
    add_theme_page( 'Customize', 'Customize', 'edit_theme_options', 'customize.php' );
}

/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';